==> libtcod_1.14.0+dfsg.orig.tar.xz: libtcod-1.14.0/src/libtcod/sdl2/event.cpp <==
/* BSD 3-Clause License
 *
 * Copyright © 2008-2019, Jice and the libtcod contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#include "event.h"

#include <cstring>

#include "../libtcod_int.h"
#include "../engine/globals.h"

#include <SDL.h>
namespace tcod {
namespace sdl2 {
TCOD_event_t process_event(const union SDL_Event& ev,
                           TCOD_key_t& key) noexcept
{
  return TCOD_sys_handle_key_event(&ev, &key);
}
TCOD_event_t process_event(const union SDL_Event& ev,
                           TCOD_mouse_t& mouse) noexcept
{
  return TCOD_sys_handle_mouse_event(&ev, &mouse);
}
} // namespace sdl2
} // namespace tcod
TCOD_event_t TCOD_sys_process_key_event(
    const union SDL_Event* in, TCOD_key_t* out)
{
  if (!in || !out) { return TCOD_EVENT_NONE; }
  return tcod::sdl2::process_event(*in, *out);
}
TCOD_event_t TCOD_sys_process_mouse_event(
    const union SDL_Event* in, TCOD_mouse_t* out)
{
  if (!in || !out) { return TCOD_EVENT_NONE; }
  return tcod::sdl2::process_event(*in, *out);
}

==> libtcod_1.18.1+dfsg.orig.tar.xz: libtcod-1.18.1/src/libtcod/sdl2/event.cpp <==
/* BSD 3-Clause License
 *
 * Copyright © 2008-2021, Jice and the libtcod contributors.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
#include "event.h"

#include <SDL.h>

#include <cstring>

#include "../libtcod_int.h"
namespace tcod {
namespace sdl2 {
TCOD_event_t process_event(const union SDL_Event& ev, TCOD_key_t& key) noexcept {
  return TCOD_sys_handle_key_event(&ev, &key);
}
TCOD_event_t process_event(const union SDL_Event& ev, TCOD_mouse_t& mouse) noexcept {
  return TCOD_sys_handle_mouse_event(&ev, &mouse);
}
}  // namespace sdl2
}  // namespace tcod
TCOD_event_t TCOD_sys_process_key_event(const union SDL_Event* in, TCOD_key_t* out) {
  if (!in || !out) {
    return TCOD_EVENT_NONE;
  }
  return tcod::sdl2::process_event(*in, *out);
}
TCOD_event_t TCOD_sys_process_mouse_event(const union SDL_Event* in, TCOD_mouse_t* out) {
  if (!in || !out) {
    return TCOD_EVENT_NONE;
  }
  return tcod::sdl2::process_event(*in, *out);
}
